package org.tinygroup.eventnetremote;

import java.util.HashMap;
import java.util.Map;

import org.tinygroup.cepcore.CEPCore;
import org.tinygroup.cepcore.CEPCoreRemoteInterface;
import org.tinygroup.event.Event;
import org.tinygroup.event.central.Node;
import org.tinygroup.eventnet.EventServer;
import org.tinygroup.logger.LogLevel;
import org.tinygroup.logger.Logger;
import org.tinygroup.logger.LoggerFactory;

public class EventNetRemoteImpl implements CEPCoreRemoteInterface {
	private static Logger logger = LoggerFactory.getLogger(EventNetRemoteImpl.class);
	private EventServer server;
	Map<String,EventClientDaemonRunnable> clientMap = new HashMap<String, EventClientDaemonRunnable>();

	public void startCEPCore(CEPCore cep, Node node) {
		server = new EventServer(Integer.parseInt(node.getPort()));
		server.run();
	}

	public void stopCEPCore(CEPCore cep, Node node) {
		server.stop();
	}

	public Event remoteprocess(Event event, Node remoteNode) {
		String nodeInfo = remoteNode.toString();
		EventClientDaemonRunnable client = null;
		if(clientMap.containsKey(nodeInfo)){
			client = clientMap.get(nodeInfo);
		}else{
			client =  new EventClientDaemonRunnable(remoteNode.getIp(),
					Integer.parseInt(remoteNode.getPort()));
			client.run();
			clientMap.put(nodeInfo, client);
		}
		return client.getClient().sendObject(event);
		
	}

	public void removeConnect(Node remoteNode) {
		logger.logMessage(LogLevel.INFO, "开始移除连接,目标节点:{0}",remoteNode.toString());
		String nodeInfo = remoteNode.toString();
		if(clientMap.containsKey(nodeInfo)){
			clientMap.get(nodeInfo).stop();
			logger.logMessage(LogLevel.INFO, "移除连接完成,目标节点:{0}",remoteNode.toString());
		}else{
			logger.logMessage(LogLevel.INFO, "连接不存在,无需移除,目标节点:{0}",remoteNode.toString());
		}
	}

}
